@@ -1,6 +1,6 @@
 /* request.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: request.cc,v 1.33 2004/10/31 15:56:20 ralf Exp $ */
+/* $Id: request.cc,v 1.34 2005/03/24 07:11:40 ralf Exp $ */
 
 #include "request.h"
 #include "aguix.h"
@@ -28,6 +28,9 @@
 #include "message.h"
 #include "stringgadget.h"
 #include "bevelbox.h"
+#include "acontainer.h"
+#include "acontainerbb.h"
+#include "choosebutton.h"
 
 #define ACCEPT_ENTER_FOR_CHOOSE 1
 
@@ -435,3 +438,212 @@ int Requester::string_request( const char *title, const char *text, const char *
   _freesafe(buts);
   return endmode;
 }
+
+int Requester::request_choose( const char *title, const char *text, const char *choose_text, bool &choose_var, const char *buttons )
+{
+  return request_choose( title, text, choose_text, choose_var, buttons, REQUEST_NONE );
+}
+
+int Requester::request_choose( const char *title, const char *text, const char *choose_text, bool &choose_var, const char *buttons, request_flags_t flags )
+{
+  return request_choose( title, text, choose_text, choose_var, buttons, NULL, flags );
+}
+
+int Requester::request_choose( const char *title,
+			       const char *text,
+			       const char *choose_text,
+			       bool &choose_var,
+			       const char *buttons,
+			       AWindow *twin,
+			       request_flags_t flags )
+{
+  int i;
+  Button **buts;
+  int nbuttons;
+  char **buttonss;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
+  const int cfixnr = AContainer::ACONT_MINH +
+                     AContainer::ACONT_MINW +
+                     AContainer::ACONT_MAXH +
+                     AContainer::ACONT_MAXW +
+                     AContainer::ACONT_NORESIZE;
+  int lines;
+  char **liness;
+
+  nbuttons = createLines( buttons, &buttonss );
+  AWindow *win = new AWindow( aguix );
+  win->create( NULL, 10, 10, 10, 10, 0, title );
+  if ( twin != NULL ) {
+    win->setTransientForAWindow( twin );
+  } else if ( transientawin != NULL ) {
+    win->setTransientForAWindow( transientawin );
+  } else {
+    if ( aguix->getTransientWindow() != NULL ) {
+      win->setTransientForAWindow( aguix->getTransientWindow() );
+    }
+  }
+
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  lines = createLines( text, &liness );
+
+  AContainerBB *ac1_1 = static_cast<AContainerBB*>( ac1->add( new AContainerBB( win, 1, lines ), 0, 0 ) );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( 5 );
+
+  for ( i = 0; i < lines; i++ ) {
+    ac1_1->add( new Text( aguix, 0, 0, liness[i], 1 ),
+		0, i, cincwnr );
+  }
+  
+  for ( i = 0; i < lines; i++ ) _freesafe( liness[i] );
+  _freesafe( liness );
+
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 3, 1 ), 0, 1 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  ChooseButton *cb1 = (ChooseButton*)ac1_2->add( new ChooseButton( aguix, 0,
+								   0, choose_var,
+								   choose_text, LABEL_RIGHT, 1, 1 ),
+						 1, 0, cfixnr );
+  AContainer *ac1_3 = ac1->add( new AContainer( win, nbuttons, 1 ), 0, 2 );
+  ac1_3->setMinSpace( 5 );
+  ac1_3->setMaxSpace( -1 );
+  ac1_3->setBorderWidth( 0 );
+
+  buts = (Button**)_allocsafe( nbuttons * sizeof( Button* ) );
+  for ( i = 0; i < nbuttons; i++ ) {
+    buts[i] = (Button*)ac1_3->add( new Button( aguix, 0, 0, buttonss[i], 1, 0, i ),
+				   i, 0, cfix );
+  }
+  for ( i = 0; i < nbuttons; i++ ) {
+    buts[i]->setAcceptFocus( true );
+  }
+  buts[0]->takeFocus();
+
+  win->setDoTabCycling( true );
+  win->contMaximize( true, true );
+
+  win->useStippleBackground();
+  win->centerScreen();
+  win->show();
+
+  AGMessage *msg;
+  int endmode = -1;
+  for( ; endmode == -1; ) {
+    msg = aguix->WaitMessage( win );
+    if ( msg != NULL ) {
+      switch ( msg->type ) {
+        case AG_CLOSEWINDOW:
+          if ( msg->closewindow.window == win->getWindow() ) {
+	    if ( ( flags & REQUEST_CANCELWITHLEFT ) != 0 ) {
+	      endmode = 0;
+	    } else {
+	      endmode = nbuttons - 1;
+	    }
+	  }
+          break;
+        case AG_BUTTONCLICKED:
+	  for ( i = 0; i < nbuttons; i++ ) {
+	    if ( msg->button.button == buts[i] ) {
+	      endmode = i;
+	      break;
+	    }
+	  }
+          break;
+	case AG_KEYPRESSED:
+	  if ( win->isParent( msg->key.window, false ) == true ) {
+	    switch(msg->key.key) {
+	      case XK_KP_Enter:
+	      case XK_Return:
+#ifdef ACCEPT_ENTER_FOR_CHOOSE
+		for ( i = 0; i < nbuttons; i++ ) {
+		  if ( buts[i]->hasFocus() == true ) {
+		    endmode = i;
+		    break;
+		  }
+		}
+#else
+		if ( buts[0]->hasFocus() == true ) endmode = 0;
+#endif
+		break;
+	      case XK_Escape:
+		if ( ( flags & REQUEST_CANCELWITHLEFT ) != 0 ) {
+		  endmode = 0;
+		} else {
+		  endmode = nbuttons - 1;
+		}
+		break;
+	      case XK_F1:
+	        endmode = 0;
+	        break;
+	      case XK_F2:
+	        endmode = 1;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F3:
+	        endmode = 2;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F4:
+	        endmode = 3;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F5:
+	        endmode = 4;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F6:
+	        endmode = 5;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F7:
+	        endmode = 6;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F8:
+	        endmode = 7;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F9:
+	        endmode = 8;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F10:
+	        endmode = 9;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_Left:
+		win->prevFocus();
+		break;
+  	      case XK_Right:
+		win->nextFocus();
+		break;
+	    }
+	  }
+	  break;
+      }
+      aguix->ReplyMessage( msg );
+    }
+  }
+
+  choose_var = ( cb1->getState() == 0 ) ? false : true;
+
+  win->close();
+  delete win;
+  for ( i = 0; i < nbuttons; i++ ) _freesafe( buttonss[i] );
+  _freesafe( buttonss );
+  _freesafe( buts );
+  return endmode;
+}
