@@ -1,6 +1,6 @@
 /* stringgadget.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: stringgadget.cc,v 1.41 2004/10/27 20:43:32 ralf Exp $ */
+/* $Id: stringgadget.cc,v 1.48 2005/03/22 18:40:46 ralf Exp $ */
 
 #include "stringgadget.h"
 #include "awindow.h"
@@ -54,6 +54,7 @@ StringGadget::StringGadget(AGUIX *taguix):GUIElement(taguix)
   twin = 0;
   canHandleFocus = true;
   setAcceptFocus( true );
+  passwordMode = false;
 }
 
 StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,int height,const char *ttext,int tdata):GUIElement(taguix)
@@ -84,6 +85,7 @@ StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,int height,cons
   twin = 0;
   canHandleFocus = true;
   setAcceptFocus( true );
+  passwordMode = false;
 }
 
 StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,const char *ttext,int tdata):GUIElement(taguix)
@@ -98,7 +100,6 @@ StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,const char *tte
   this->h=taguix->getCharHeight()+2+6;
   xoffset=0;
   cursorpos=0;
-  xoffset=0;
   active=false;
   this->text=dupstring(ttext);
   tbg=-1;
@@ -112,6 +113,7 @@ StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,const char *tte
   twin = 0;
   canHandleFocus = true;
   setAcceptFocus( true );
+  passwordMode = false;
 }
 
 void StringGadget::resize(int tw,int th)
@@ -166,6 +168,8 @@ void StringGadget::tredraw()
   int maxcol=aguix->getMaxCols();
   int newbg;
   GC usegc;
+  int minx, maxx;
+
   if(parent==NULL) return;
   if(active==true) {
     if(maxcol>7) {
@@ -194,38 +198,48 @@ void StringGadget::tredraw()
   double f1=((h-6-2)/2)-(ch/2);
   int dy=(int)f1;
   int x1,x2;
+  int len;
+
   x1=(selstart<=selend?selstart:selend);
   x2=(selstart>selend?selstart:selend);
   if((x2==(int)strlen(text))&&(selstart!=selend)) x2--;
-
-  //TODO: warum zur Hoelle habe ich den zweiten Test hier eingebaut?????
-  //  if((xoffset<x1)&&((x1-xoffset)<=maxdisplay)) {
-  // so muesste es doch auch gehen
+  
   if( xoffset < x1 ) {
     // links vom x1 ist noch Text
     aguix->setFG(usegc,1);
-    strncpy(tstr,text+xoffset, a_min( x1-xoffset, maxdisplay ) );
-    tstr[ a_min( x1-xoffset, maxdisplay) ]=0;
+    
+    len = a_min( x1 - xoffset, maxdisplay );
+
+    if ( passwordMode == true ) {
+      memset( tstr, '*', len );
+    } else {
+      strncpy( tstr, text + xoffset, len );
+    }
+    tstr[ len ]=0;
     if(font==NULL) aguix->DrawText(twin,tstr,dx,dy);
     else aguix->DrawText(twin,font,tstr,dx,dy);
     dx+=strlen(tstr)*cw;
   }
-  //TODO: wiederum: wozu diese Berechnung, x1 ist doch < x2 (siehe oben)
-  int maxx=(x1<x2)?x2:x1;
-  int minx=(x1<x2)?x1:x2;
-  if(!((maxx<xoffset)||((minx-xoffset)>/*=*/maxdisplay))) {
+  if ( ! ( ( x2 < xoffset ) || ( ( x1 - xoffset ) > maxdisplay ) ) ) {
     // die Selektion ist sichtbar
     minx=(x1<xoffset)?xoffset:x1;
     maxx=(x2<(xoffset+maxdisplay))?x2:(xoffset+maxdisplay-1);
-    int tl=maxx-minx+1;
-    strncpy(tstr,text+minx,tl);
-    tstr[tl]=0;
+    len = maxx - minx + 1;
+    if ( passwordMode == true ) {
+      if ( *( text + minx ) != '\0' )
+	memset( tstr, '*', len );
+      else
+	tstr[0] = '\0';
+    } else {
+      strncpy( tstr, text + minx, len );
+    }
+    tstr[len] = 0;
     if(active==true) {
       aguix->setFG(usegc,1);
     } else {
       aguix->setFG(usegc,0);
     }
-    aguix->FillRectangle(twin,usegc,dx,dy,tl*cw,ch);
+    aguix->FillRectangle( twin, usegc, dx, dy, len * cw, ch );
     if(active==true) {
       if(maxcol>7) {
 	aguix->setFG(usegc,7);
@@ -237,15 +251,29 @@ void StringGadget::tredraw()
     }
     if(font==NULL) aguix->DrawText(twin,tstr,dx,dy);
     else aguix->DrawText(twin,font,tstr,dx,dy);
-    dx+=tl*cw;
+    dx += len * cw;
   }
   if((x2-xoffset)<(maxdisplay-1)) {
-    int t1;
-    t1=x2+1;
-    if(t1<x2) t1=x2;
-    if((int)strlen(text)>=t1) {
-      strncpy(tstr,text+t1,maxdisplay-(x2-xoffset)-1);
-      tstr[maxdisplay-(x2-xoffset)-1]=0;
+    // Rest nach Selektion ist sichtbar
+    int first_vis_char;
+    
+    // end of selection can be less than xoffset
+    first_vis_char = a_max( x2 + 1, xoffset );
+    
+    if ( (int)strlen( text ) >= first_vis_char ) {
+      // as x2 can be less than xoffset, don't take more
+      // than maxdisplay
+      len = a_min( maxdisplay, maxdisplay - ( x2 - xoffset ) - 1 );
+      
+      if ( passwordMode == true ) {
+	len = a_min( len, (int)strlen( text ) - first_vis_char );
+	if ( len < 0 ) len = 0;
+	memset( tstr, '*', len );
+      } else {
+	strncpy( tstr, text + first_vis_char, len );
+      }
+      tstr[ len ] = 0;
+      
       aguix->setFG(usegc,1);
       if(font==NULL) aguix->DrawText(twin,tstr,dx,dy);
       else aguix->DrawText(twin,font,tstr,dx,dy);
@@ -581,14 +609,11 @@ void StringGadget::setText(const char *new_text)
 {
   _freesafe(text);
   text=dupstring(new_text);
-  if((xoffset+maxdisplay)>=(int)strlen(new_text)) {
-    xoffset=(int)strlen(new_text)-maxdisplay;
-    if(xoffset<0) xoffset=0;
-  }
   if(cursorpos>=(int)strlen(new_text)) {
     cursorpos=(int)strlen(new_text);
   }
   selstart=selend=cursorpos;
+  setXOffset( xoffset );
   tredraw();
 }
 
@@ -640,16 +665,17 @@ void StringGadget::applySelection()
 {
   int x1,x2;
   char *buffer;
-  x1=(selstart<=selend?selstart:selend);
-  x2=(selstart>selend?selstart:selend);
-  if(x2==(int)strlen(text)) x2--;
-  if(x1<x2) {
-    //    XStoreBytes(aguix->getDisplay(),text+x1,x2-x1+1);
-    buffer=dupstring(text+x1);
-    buffer[x2-x1+1]=0;
-    aguix->startCut(this,buffer);
-    _freesafe(buffer);
-    //    aguix->Flush();
+
+  if ( passwordMode == false ) {
+    x1=(selstart<=selend?selstart:selend);
+    x2=(selstart>selend?selstart:selend);
+    if(x2==(int)strlen(text)) x2--;
+    if(x1<x2) {
+      buffer=dupstring(text+x1);
+      buffer[x2-x1+1]=0;
+      aguix->startCut(this,buffer);
+      _freesafe(buffer);
+    }
   }
 }
 
@@ -675,27 +701,9 @@ void StringGadget::removeSelection()
 void StringGadget::insertSelection()
 {
   if ( parent == NULL ) return;
-#if 0
-  Display *display=aguix->getDisplay();
-#endif
   int nbytes_return;
   char *bytes_return,*tstr;
-#if 0
-  bytes_return=XFetchBytes(display,&nbytes_return);
-  if((nbytes_return>0)&&(bytes_return)) {
-    // an Cursorpos einfgen
-    int tl=strlen(text);
-    tstr=(char*)_allocsafe(tl+nbytes_return+2);
-    strncpy(tstr,text,cursorpos);
-    tstr[cursorpos]=0;
-    strncat(tstr,bytes_return,nbytes_return);
-    tstr[cursorpos+nbytes_return]=0;
-    strcat(tstr,text+cursorpos);
-    _freesafe(text);
-    text=tstr;
-  }
-  if(bytes_return) XFree(bytes_return);
-#else
+
   if(aguix->amiOwner()==true) {
     bytes_return=dupstring(aguix->getCutBuffer());
     nbytes_return=strlen(bytes_return);
@@ -716,7 +724,6 @@ void StringGadget::insertSelection()
     wantpaste=true;
     pasterequest=time(NULL);
   }
-#endif
 }
 
 int StringGadget::setFont(char *fontname)
@@ -755,8 +762,8 @@ void StringGadget::setXOffset( int new_pos )
 {
   xoffset = new_pos;
 
-  if ( ( xoffset + maxdisplay ) >= (int)strlen( text ) ) {
-    xoffset = (int)strlen( text ) - maxdisplay;
+  if ( ( xoffset + maxdisplay - 1) > (int)strlen( text ) ) {
+    xoffset = (int)strlen( text ) - maxdisplay + 1;
   }
   if ( xoffset < 0 ) xoffset = 0;
   tredraw();
@@ -909,3 +916,9 @@ void StringGadget::selectAll()
   applySelection();
   tredraw();
 }
+
+void StringGadget::setPasswordMode( bool nv )
+{
+  passwordMode = nv;
+  redraw();
+}
