@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: stringgadget.h,v 1.16 2004/10/27 20:43:26 ralf Exp $ */
+/* $Id: stringgadget.h,v 1.17 2005/03/20 20:44:56 ralf Exp $ */
 
 #ifndef STRINGGADGET_H
 #define STRINGGADGET_H
@@ -64,6 +64,7 @@ public:
   virtual void leaveFocus();
   void insertAtCursor( const char *str );
   void selectAll();
+  void setPasswordMode( bool nv );
 protected:
   virtual void doCreateStuff();
   virtual void doDestroyStuff();
@@ -93,6 +94,7 @@ private:
 
   bool wantpaste;
   time_t pasterequest;
+  bool passwordMode;
 };
 
 #endif
