@@ -1,7 +1,7 @@
 /* text.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
  * Copyright (C) 2001-2004 Ralf Hoffmann.
- * You can contact me at: ralf.hoffmann@epost.de
+ * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: text.cc,v 1.9 2004/03/18 07:03:26 ralf Exp $ */
+/* $Id: text.cc,v 1.11 2004/10/27 20:43:21 ralf Exp $ */
 
 #include "text.h"
 #include "lowlevelfunc.h"
@@ -33,6 +33,8 @@ Text::Text(AGUIX *taguix):GUIElement(taguix)
   color=1;
   bgset=false;
   font=NULL;
+  bg = 0;
+  ownbg = false;
 }
 
 Text::Text(AGUIX *taguix,int tx,int ty,const char *ttext,int tcolor):GUIElement(taguix)
@@ -45,6 +47,22 @@ Text::Text(AGUIX *taguix,int tx,int ty,const char *ttext,int tcolor):GUIElement(
   this->color=tcolor;
   bgset=false;
   font=NULL;
+  bg = 0;
+  ownbg = false;
+}
+
+Text::Text( AGUIX *taguix, int tx, int ty, const char *ttext, int tfg, int tbg ):GUIElement( taguix )
+{
+  this->text = dupstring( ttext );
+  this->x = tx;
+  this->y = ty;
+  this->w = taguix->getCharWidth() * strlen( ttext ) + 1;
+  this->h = taguix->getCharHeight();
+  this->color = tfg;
+  bgset = false;
+  font = NULL;
+  bg = tbg;
+  ownbg = true;
 }
 
 Text::~Text()
@@ -88,9 +106,13 @@ void Text::redraw()
   if(parent!=NULL) {
     if(font==NULL) usegc=0;
     else usegc=font->getGC();
-    if(bgset==false) {
-      aguix->SetWindowBG(win,parent->getBG());
-      bgset=true;
+    if ( bgset == false ) {
+      if ( ownbg == true ) {
+	aguix->SetWindowBG( win, bg );
+      } else {
+	aguix->SetWindowBG( win, parent->getBG() );
+      }
+      bgset = true;
     }
     aguix->ClearWin(win);
     aguix->setFG(usegc,color);
@@ -134,3 +156,28 @@ bool Text::isType(const char *qtype) const
   if(strcmp(type,qtype)==0) return true;
   return false;
 }
+
+void Text::setBG( int tcolor )
+{
+  if ( ( tcolor < ( aguix->getMaxCols() ) ) && ( tcolor >= 0 ) ) {
+    bg = tcolor;
+    ownbg = true;
+    bgset = false;
+    redraw();
+  }
+}
+
+int Text::getBG() const
+{
+  return bg;
+}
+
+void Text::setFG( int tcolor )
+{
+  setColor( tcolor );
+}
+
+int Text::getFG() const
+{
+  return color;
+}
