@@ -1,6 +1,6 @@
 /* condparser.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004 Ralf Hoffmann.
+ * Copyright (C) 2004-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: condparser.cc,v 1.6 2004/10/27 21:06:21 ralf Exp $ */
+/* $Id: condparser.cc,v 1.7 2005/03/08 22:38:11 ralf Exp $ */
 
 #include "condparser.h"
 #include <aguix/lowlevelfunc.h>
@@ -43,7 +43,8 @@ struct CondParser::deftokens CondParser::keywords[] = {
   { "contentStr", CondParser::TOK_CONTENTSTR },
   { "contentNum", CondParser::TOK_CONTENTNUM },
   { "name", CondParser::TOK_NAME },
-  { "fullname", CondParser::TOK_FULLNAME }
+  { "fullname", CondParser::TOK_FULLNAME },
+  { "isLocal", CondParser::TOK_ISLOCAL }
 };
 
 struct CondParser::flaghelp CondParser::flags[] = {
@@ -55,6 +56,7 @@ struct CondParser::flaghelp CondParser::flags[] = {
   { "isSock()", 580, -1 },
   { "isFIFO()", 581, -1 },
   { "isSymlink()", 582, -1 },
+  { "isLocal()", 626, -1 },
   { "size()", 583, -1 },
   { "perm(mask)", 584, -1 },
   { "toLower(...)", 585, -1 },
@@ -865,6 +867,20 @@ CondParser::erg_t *CondParser::factor()
       e->wasstring = 1;
       e->numval = atoi( e->strval );
       break;
+    case TOK_ISLOCAL:
+      if ( match( TOK_ISLOCAL ) ) return NULL;
+      if ( match( '(' ) ) return NULL;
+      if ( match( ')' ) ) return NULL;
+      e = (erg_t*)_allocsafe( sizeof( erg_t ) );
+      e->wasstring = 0;
+      if ( fe == NULL ) {
+        e->numval = 0;
+      } else {
+        e->numval = worker_islocal( fe->fullname );
+      }
+      e->strval = (char*)_allocsafe( A_BYTESFORNUMBER( e->numval ) );
+      sprintf( e->strval, "%d", e->numval );
+      break;
     default:
       return NULL;
   }
