@@ -297,12 +297,22 @@
      SELECTACTIVECOLOR_WCP = 520,
      COLOREXTERNPROG_WCP = 521,
      PARENT_WCP = 522,
-     ERROR = 523,
-     ACTIVESIDE_WCP = 524,
-     SHOWFREESPACE_WCP = 525,
-     ACTIVEMODE_WCP = 526,
-     STRING_WCP = 527,
-     NUM_WCP = 528
+     DONTCD_WCP = 523,
+     DONTCHECKVIRTUAL_WCP = 524,
+     GOFTPOP_WCP = 525,
+     HOSTNAME_WCP = 526,
+     USERNAME_WCP = 527,
+     PASSWORD_WCP = 528,
+     DONTENTERFTP_WCP = 529,
+     ALWAYSSTOREPW_WCP = 530,
+     ERROR = 531,
+     ACTIVESIDE_WCP = 532,
+     SHOWFREESPACE_WCP = 533,
+     ACTIVEMODE_WCP = 534,
+     ASK_WCP = 535,
+     SSHALLOW_WCP = 536,
+     STRING_WCP = 537,
+     NUM_WCP = 538
    };
 #endif
 #define LEFTBRACE_WCP 258
@@ -570,12 +580,22 @@
 #define SELECTACTIVECOLOR_WCP 520
 #define COLOREXTERNPROG_WCP 521
 #define PARENT_WCP 522
-#define ERROR 523
-#define ACTIVESIDE_WCP 524
-#define SHOWFREESPACE_WCP 525
-#define ACTIVEMODE_WCP 526
-#define STRING_WCP 527
-#define NUM_WCP 528
+#define DONTCD_WCP 523
+#define DONTCHECKVIRTUAL_WCP 524
+#define GOFTPOP_WCP 525
+#define HOSTNAME_WCP 526
+#define USERNAME_WCP 527
+#define PASSWORD_WCP 528
+#define DONTENTERFTP_WCP 529
+#define ALWAYSSTOREPW_WCP 530
+#define ERROR 531
+#define ACTIVESIDE_WCP 532
+#define SHOWFREESPACE_WCP 533
+#define ACTIVEMODE_WCP 534
+#define ASK_WCP 535
+#define SSHALLOW_WCP 536
+#define STRING_WCP 537
+#define NUM_WCP 538
 
 
 
@@ -587,7 +607,7 @@ typedef union {
   char *strptr;
 } yystype;
 /* Line 1281 of /usr/share/bison/yacc.c.  */
-#line 591 "configparser.tab.h"
+#line 611 "configparser.tab.h"
 # define YYSTYPE yystype
 #endif
 
