@@ -1,6 +1,6 @@
 /* configtokens.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2003-2004 Ralf Hoffmann.
+ * Copyright (C) 2003-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: configtokens.cc,v 1.15 2004/10/27 21:06:34 ralf Exp $ */
+/* $Id: configtokens.cc,v 1.19 2005/03/23 21:57:28 ralf Exp $ */
 
 #include "wdefines.h"
 #include <aguix/util.h>
@@ -291,7 +291,17 @@ struct mytoken tokenlist[]={
   { SELECTCOLOR_WCP, "selectcolor" },
   { UNSELECTACTIVECOLOR_WCP, "unselectactivecolor" },
   { SELECTACTIVECOLOR_WCP, "selectactivecolor" },
-  { PARENT_WCP, "parent" }
+  { PARENT_WCP, "parent" },
+  { DONTCD_WCP, "dontcd" },
+  { DONTCHECKVIRTUAL_WCP, "dontcheckvirtual" },
+  { GOFTPOP_WCP, "goftpop" },
+  { HOSTNAME_WCP, "hostname" },
+  { USERNAME_WCP, "username" },
+  { PASSWORD_WCP, "password" },
+  { DONTENTERFTP_WCP, "dontenterftp" },
+  { ALWAYSSTOREPW_WCP, "alwaysstorepw" },
+  { ASK_WCP, "ask" },
+  { SSHALLOW_WCP, "sshallow" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
