@@ -1,6 +1,6 @@
 /* datei.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: datei.cc,v 1.102 2004/12/16 19:12:36 ralf Exp $ */
+/* $Id: datei.cc,v 1.111 2005/03/29 20:38:34 ralf Exp $ */
 
 #include "datei.h"
 #include <aguix/lowlevelfunc.h>
@@ -37,69 +37,100 @@
 #define MAXPATHLEN 2048
 #endif
 
-int datelen=-1;
-
 Datei::Datei()
 {
-  fp=NULL;
+  fd = -1;
   error=0;
+  iseof = false;
 }
 
 Datei::~Datei()
 {
-  if(fp!=NULL) close();
+  if ( fd >= 0 ) close();
 }
 
 int Datei::open( const char *name, const char *mode )
 {
-  fp = worker_fopen( name, mode );
-  if(fp==NULL) return 1;
+  int m;
+  mode_t p;
+
+  if ( name == NULL ) return 1;
+  if ( mode == NULL ) return 1;
+
+  if ( strlen( mode ) < 1 ) return 1;  // wrong mode
+
+  //TODO: Currently "b" in mode will fail open in any case
+  
+  p = 0;
+  if ( strcasecmp( mode, "r" ) == 0 ) {
+    m = O_RDONLY;
+  } else if ( strcasecmp( mode, "r+" ) == 0 ) {
+    m = O_RDWR;
+  } else if ( strcasecmp( mode, "w" ) == 0 ) {
+    m = O_WRONLY | O_CREAT | O_TRUNC;
+    p = S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH;
+  } else if ( strcasecmp( mode, "w+" ) == 0 ) {
+    m = O_RDWR | O_CREAT | O_TRUNC;
+    p = S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH;
+  } else if ( strcasecmp( mode, "a" ) == 0 ) {
+    m = O_WRONLY | O_CREAT | O_APPEND;
+    p = S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH;
+  } else if ( strcasecmp( mode, "a+" ) == 0 ) {
+    m = O_RDWR | O_CREAT | O_APPEND;
+    p = S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH;
+  } else {
+    return 1;
+  }
+  fd = ::worker_open( name, m, p );
+  if ( fd < 0 ) return 1;
+  iseof = false;
   return 0;
 }
 
 void Datei::close()
 {
-  if(fp==NULL) return;
-  worker_fclose( fp );
-  fp=NULL;
+  if ( fd < 0 ) return;
+  ::worker_close( fd );
+  fd = -1;
+  iseof = false;
 }
 
 int Datei::putUChar(unsigned char value)
 {
-  if(fp==NULL) return -1;
+  if ( fd < 0 ) return -1;
   int x;
-  x=fputc(value,fp);
+  x = putCharacter( value );
   if(x!=EOF) return 1;
-  printf("fehler bei FPutChar\n");
+  printf("fehler bei PutChar\n");
   return 0;
 }
 
 int Datei::putUShort(unsigned short int value)
 {
-  if(fp==NULL) return -1;
+  if ( fd < 0 ) return -1;
   int x;
-  x=fputc(value>>8,fp);
+  x = putCharacter( value >> 8 );
   if(x==EOF) return 0;
-  x=fputc(value&0xff,fp);
+  x = putCharacter( value & 0xff );
   if(x==EOF) return 1;
   return 2;
 }
 
 int Datei::putInt(int value)
 {
-  if(fp==NULL) return -1;
+  if ( fd < 0 ) return -1;
   int x,tv;
   if(value<0) {
-    x=fputc(1,fp);
+    x = putCharacter( 1 );
     if(x==EOF) return 0;
   } else {
-    x=fputc(0,fp);
+    x = putCharacter( 0 );
     if(x==EOF) return 0;
   }
   tv=abs(value);
   int i;
   for(i=0;i<4;i++) {
-    x=fputc(tv&0xff,fp);
+    x = putCharacter( tv & 0xff );
     if(x==EOF) return i+1;
     tv>>=8;
   }
@@ -108,16 +139,16 @@ int Datei::putInt(int value)
 
 int Datei::getInt()
 {
-  if(fp==NULL) return -1;
+  if ( fd < 0 ) return -1;
   int vz,x,value;
-  vz=fgetc(fp);
+  vz = getCharacter();
   if(vz<0) {
     error++;
     return 0;
   }
   value=0;
   for(int i=0;i<4;i++) {
-    x=fgetc(fp);
+    x = getCharacter();
     if(x==EOF) {
       error++;
       return 0;
@@ -130,36 +161,40 @@ int Datei::getInt()
 
 int Datei::putULong(unsigned long value)
 {
-  if(fp==NULL) return -1;
+  if ( fd < 0 ) return -1;
   int x;
-  x=fputc((value&0xff000000)>>24,fp);
+  x = putCharacter( ( value & 0xff000000 ) >> 24 );
   if(x==EOF) return 0;
-  x=fputc((value&0xff0000)>>16,fp);
+  x = putCharacter( ( value & 0xff0000 ) >> 16 );
   if(x==EOF) return 1;
-  x=fputc((value&0xff00)>>8,fp);
+  x = putCharacter( ( value & 0xff00 ) >> 8 );
   if(x==EOF) return 2;
-  x=fputc(value&0xff,fp);
+  x = putCharacter( value & 0xff );
   if(x==EOF) return 3;
   return 4;
 }
 
 int Datei::putString( const char *str1 )
 {
-  if(fp==NULL) return -1;
-  int x;
-  x=fputs(str1,fp);
-  if(x==EOF) return -2;
-  return strlen(str1);
+  int x, l;
+
+  if ( fd < 0 ) return -1;
+  if ( str1 == NULL ) return -1;
+  
+  l = strlen( str1 );
+  x = worker_write( fd, str1, l );
+  if ( x < 0 ) return -2;
+  return x;
 }
 
 unsigned char Datei::getUChar()
 {
-  if(fp==NULL) {
+  if ( fd < 0 ) {
     error++;
     return 0;
   }
   int x;
-  x=fgetc(fp);
+  x = getCharacter();
   if(x==EOF) {
     error++;
     return 0;
@@ -169,28 +204,28 @@ unsigned char Datei::getUChar()
 
 int Datei::getCharAsInt()
 {
-  if(fp==NULL) {
+  if ( fd < 0 ) {
     error++;
     return 0;
   }
-  return fgetc(fp);
+  return getCharacter();
 }
 
 unsigned short Datei::getUShort()
 {
-  if(fp==NULL) {
+  if ( fd < 0 ) {
     error++;
     return 0;
   }
   int x;
   unsigned short int a;
-  x=fgetc(fp);
+  x = getCharacter();
   if(x==EOF) {
     error++;
     return 0;
   }
   a=((unsigned int)x)*0x100;
-  x=fgetc(fp);
+  x = getCharacter();
   if(x==EOF) {
     error++;
     return 1;
@@ -201,31 +236,31 @@ unsigned short Datei::getUShort()
 
 unsigned long Datei::getULong()
 {
-  if(fp==NULL) {
+  if ( fd < 0 ) {
     error++;
     return 0;
   }
   int x;
   unsigned long a;
-  x=fgetc(fp);
+  x = getCharacter();
   if(x==EOF) {
     error++;
     return 0;
   }
   a=((unsigned int)x)*0x1000000;
-  x=fgetc(fp);
+  x = getCharacter();
   if(x==EOF) {
     error++;
     return 1;
   }
   a+=((unsigned int)x)*0x10000;
-  x=fgetc(fp);
+  x = getCharacter();
   if(x==EOF) {
     error++;
     return 2;
   }
   a+=((unsigned int)x)*0x100;
-  x=fgetc(fp);
+  x = getCharacter();
   if(x==EOF) {
     error++;
     return 3;
@@ -236,7 +271,7 @@ unsigned long Datei::getULong()
 
 char *Datei::getString(int count)
 {
-  if(fp==NULL) return NULL;
+  if ( fd < 0 ) return NULL;
   unsigned char *tstr,*tstr2;
   int ch;
   long x;
@@ -247,7 +282,7 @@ char *Datei::getString(int count)
     tstr=(unsigned char*)_allocsafe(size);
     x=0;
     do {
-      ch=fgetc(fp);
+      ch = getCharacter();
       if(ch!=EOF) {
         tstr[x++]=(unsigned char)ch;
       } else {
@@ -267,7 +302,7 @@ char *Datei::getString(int count)
     tstr=(unsigned char*)_allocsafe(count+1);
     if(tstr!=NULL) {
       for(x=0;x<count;x++) {
-        ch=fgetc(fp);
+	ch = getCharacter();
         tstr[x]=(unsigned char)ch;
       }
       tstr[count]=0;
@@ -365,7 +400,7 @@ int Verzeichnis::readDir( const char *dirstr, bool dontWarnInvalid )
   std::string str1;
   
   fe1=NULL;
-  dir=opendir(dirstr);
+  dir = worker_opendir( dirstr );
   if(dir!=NULL) {
 //    worker_readdir( dir );  /* berspringt den Eintrag "." */
     havepointpoint=-1;
@@ -422,7 +457,7 @@ int Verzeichnis::readDir( const char *dirstr, bool dontWarnInvalid )
       }
       if ( user_abort == true ) break;
     }
-    closedir(dir);
+    worker_closedir( dir );
     if ( user_abort == false ) {
       if(havepointpoint==-1) {
         // there is no parent-dir-entry
@@ -737,10 +772,22 @@ char *HandlePath(const char *pathstr)
       if(strcmp(buffer,".")==0) {
         y++;
       } else if(strcmp(buffer,"..")==0) {
+	if ( strchr( newpath, '/' )  == NULL ) {
+	  // no previous dir so keep ".."
+	  newpath2 = (char*)_allocsafe( strlen( newpath ) + 3 + 1);
+          if ( ( strlen( newpath ) > 0 ) && ( newpath[ strlen( newpath ) - 1 ] != '/' ) ) {
+	    sprintf( newpath2, "%s/..", newpath );
+	  } else {
+	    sprintf( newpath2, "%s..", newpath );
+	  }
+	  _freesafe( newpath );
+	  newpath = newpath2;
+	} else {
+	  newpath2=ParentDir(newpath,NULL);
+	  _freesafe(newpath);
+	  newpath=newpath2;
+	}
         y++;
-        newpath2=ParentDir(newpath,NULL);
-        _freesafe(newpath);
-        newpath=newpath2;
       } else {
         newpath2=(char*)_allocsafe(strlen(newpath)+1+strlen(buffer)+1);
         strcpy(newpath2,newpath);
@@ -867,7 +914,7 @@ Datei::d_fe_t Datei::lfileExistsExt(const char*name)
 
 void Datei::seek(long offset,int mode)
 {
-  if ( fp != NULL ) worker_fseek( fp, offset, mode );
+  if ( fd >= 0 ) worker_lseek( fd, offset, mode );
 }
 
 int getOwnerStringLen(uid_t user,gid_t gr)
@@ -983,7 +1030,7 @@ char *FileEntry::getDestination() const
   char *str=NULL,*tstr;
   if((isLink==true)&&(fullname!=NULL)) {
     tstr=(char*)_allocsafe((MAXPATHLEN+1)*sizeof(char));
-    int x=readlink(fullname,tstr,MAXPATHLEN);
+    int x = worker_readlink( fullname, tstr, MAXPATHLEN );
     if(x>=0) {
       tstr[x]=0;
       str=dupstring(tstr);
@@ -997,7 +1044,7 @@ int FileEntry::writeDestination2Buf(char *buf,int size2,bool terminated)
 {
   int x=-1;
   if((isLink==true)&&(fullname!=NULL)) {
-    x=readlink(fullname,buf,size2);
+    x = worker_readlink( fullname, buf, size2 );
     if((terminated==true)&&(x>=0)) {
       buf[x]=0;
     }
@@ -1283,26 +1330,6 @@ bool FileEntry::isExe( bool fastTest ) const
   return false;
 }
 
-int getDatelen()
-{
-  char str[128];
-  if(datelen<0) {
-    /* Erst berechnen */
-    time_t t1;
-    struct tm *mytm;
-    int x;
-    time(&t1);
-    // Alle 7 Tage messen
-    for(int i=0;i<7;i++) {
-      mytm=localtime(&t1);
-      x=strftime(str,127,"%H:%M:%S %d %b %Y",mytm);
-      if(x>datelen) datelen=x;
-      t1+=60*60*24;  // Ein Tag drauf
-    }
-  }
-  return datelen;
-}
-
 FileEntry::typecandidate_t FileEntry::runTests( WCFiletype *type,
 						bool skipcontent,
 						CondParser *condparser,
@@ -1698,7 +1725,7 @@ char *Datei::createTMPName( const char *infix )
   char *returnstr,buffer[ 2 * A_BYTESFORNUMBER( int ) ];
   int rannr;
   static int lfdnr = 0;
-  FILE *tfp;
+  int tfd;
   static MutEx lock;
   
   if ( infix == NULL ) infix = "";
@@ -1707,17 +1734,20 @@ char *Datei::createTMPName( const char *infix )
   for(;;) {
     rannr=rand();
     sprintf( buffer, "%d%d", lfdnr++, rannr );
-    returnstr = (char*)_allocsafe( strlen( "/tmp/worker" ) +
+    returnstr = (char*)_allocsafe( strlen( worker_tmpdir() ) + 
+				   strlen( "/worker" ) +
                                    strlen( infix ) + strlen( buffer ) + 1 );
-    sprintf( returnstr, "/tmp/worker%s%s", infix, buffer );
-    if(Datei::lfileExistsExt(returnstr)==Datei::D_FE_NOFILE) break;
+    sprintf( returnstr, "%s/worker%s%s", worker_tmpdir(), infix, buffer );
+    if(Datei::lfileExistsExt(returnstr)==Datei::D_FE_NOFILE) {
+      tfd = ::worker_open( returnstr, O_WRONLY | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR );
+      if ( tfd >= 0 ) {
+	::worker_close( tfd );
+	worker_chmod( returnstr, S_IRUSR | S_IWUSR );
+	break;
+      }
+    }
     _freesafe(returnstr);
   }
-  tfp = fopen( returnstr, "w" );
-  if ( tfp != NULL ) {
-    chmod( returnstr, S_IRUSR | S_IWUSR );
-    fclose( tfp );
-  }
   lock.unlock();
   return returnstr;
 }
@@ -1729,8 +1759,29 @@ char *Datei::createTMPName()
 
 int Datei::putStringExt(const char *format,const char *str)
 {
-  if(fp==NULL) return -1;
-  fprintf(fp,format,str);
+  int written, size;
+  char *tstr;
+  
+  if ( fd < 0 ) return -1;
+  if ( format == NULL ) return -1;
+  if ( str == NULL ) return -1;
+  
+  size = strlen( format ) + strlen( str ) + 1;
+  tstr = (char*)_allocsafe( size );
+  while ( 1 ) {
+    written = snprintf( tstr, size, format, str );
+    if ( ( written > -1 ) && ( written < size ) ) break;
+
+    //TODO: in case of an error we try to use more space
+    //      but if for whatever reason does not work at all
+    //      we should perhaps not end the program (because)
+    //      alloc will fail) but only quit this function
+    size *= 2;
+    _freesafe( tstr );
+    tstr = (char*)_allocsafe( size );
+  }
+  putString( tstr );
+  _freesafe( tstr );
   return 0;
 }
 
@@ -2222,19 +2273,24 @@ char *Datei::shrinkFilename( const char *str, int maxlength )
 
 int Datei::putLine( const char *str )
 {
+  int x, y, l;
+  
   if ( str == NULL ) return -1;
-  if ( fp == NULL ) return -1;
-  int x;
-  x = fputs( str, fp );
-  if ( x == EOF ) return -2;
-  x = fputs( "\n", fp );
-  if ( x == EOF ) return -2;
-  return strlen( str ) + 1;
+  if ( fd < 0 ) return -1;
+  
+  l = strlen( str );
+  x = worker_write( fd, str, l );
+  if ( x < 0 ) return -2;
+
+  y = worker_write( fd, "\n", 1 );
+  if ( y < 0 ) return -2;
+
+  return x + y;
 }
 
 char *Datei::getLine()
 {
-  if ( fp == NULL ) return NULL;
+  if ( fd < 0 ) return NULL;
   unsigned char *tstr,*tstr2;
   int ch;
   long x;
@@ -2244,7 +2300,7 @@ char *Datei::getLine()
   tstr = (unsigned char*)_allocsafe( size );
   x = 0;
   do {
-    ch = fgetc( fp );
+    ch = getCharacter();
     if ( ch != EOF ) {
       tstr[ x++ ] = (unsigned char)ch;
     } else {
@@ -2266,9 +2322,8 @@ char *Datei::getLine()
 
 bool Datei::isEOF()
 {
-  if ( fp == NULL ) return true;
-  if ( feof( fp ) != 0 ) return true;
-  return false;
+  if ( fd < 0 ) return true;
+  return iseof;
 }
 
 loff_t Datei::fileSize( const char *name )
@@ -2391,7 +2446,7 @@ char *Datei::getRelativePath( const char *source, const char *destdir )
 bool FileEntry::checkAccess( int m )
 {
   if ( fullname == NULL ) return false;
-  return ( access( fullname, m ) == 0 ) ? true : false;
+  return ( worker_access( fullname, m ) == 0 ) ? true : false;
 }
 
 char *FileEntry::getContentStr( int pos, int len )
@@ -2601,10 +2656,10 @@ const int *FileEntry::getColor( int m ) const
  */
 bool FileEntry::isSameFile( const char *othername, bool follow_symlinks ) const
 {
-  struct stat buf;
+  worker_struct_stat buf;
 
   if ( othername == NULL ) return false;
-  if ( stat( othername, &buf ) != 0 ) return false;
+  if ( worker_stat( othername, &buf ) != 0 ) return false;
 
   if ( ( isLink == true ) && ( follow_symlinks == true ) && ( isCorrupt == false ) ) {
     if ( ( dinode() == buf.st_ino ) && ( ddev() == buf.st_dev ) ) return true;
@@ -2662,7 +2717,9 @@ bool FileEntry::equals( const FileEntry &fe ) const
   if ( ( fullname == NULL ) || ( fe.fullname == NULL ) ) return false;
   
   // require same inode/device
-  if ( statbuf.inode == 0 ) return false;
+
+  //Currently disabled because AVFS can set 0
+  //  if ( statbuf.inode == 0 ) return false;
   if ( ( statbuf.inode != fe.statbuf.inode ) || ( statbuf.dev != fe.statbuf.dev ) ) return false;
 
   // require same size
@@ -2678,3 +2735,104 @@ bool FileEntry::equals( const FileEntry &fe ) const
 
   return true;
 }
+
+int Datei::putCharacter( int c )
+{
+  unsigned char cf[1];
+  int count;
+  
+  if ( fd < 0 ) return EOF;
+  
+  cf[0] = (unsigned char)c;
+  
+  count = worker_write( fd, cf, 1 );
+  if ( count < 1 ) return EOF;
+  return cf[0];
+}
+
+int Datei::getCharacter()
+{
+  unsigned char cf[1];
+  int count;
+  
+  if ( fd < 0 ) return EOF;
+  
+  count = worker_read( fd, cf, 1 );
+  
+  if ( count < 1 ) {
+    iseof = true;
+    return EOF;
+  }
+  return (int)( cf[0] );
+}
+
+int Datei::copyfile( const char *dest, const char *source )
+{
+  int fdw,fdr;
+  bool useregcopy, cancel, follow_symlinks, isCorrupt;
+  ssize_t readbytes,writebytes;
+#define BUFSIZE ( 4 * 1024 )
+  char *buf[BUFSIZE];
+  worker_struct_stat st, dst;
+  int erg;
+
+  if ( ( dest == NULL ) || ( source == NULL ) ) return 1;
+  
+  follow_symlinks = false;
+  isCorrupt = false;
+  cancel = false;
+
+  // get stat for file
+  if ( worker_lstat( source, &st ) != 0 ) return 1;
+
+  // get stat for destination if link (will fail for corrupt links)
+  // but currently I don't handle them anyway
+  if ( worker_stat( source, &dst ) != 0 ) return 1;
+  
+  useregcopy = false;
+  if ( S_ISREG( st.st_mode ) ) useregcopy = true;
+  else if ( ( S_ISLNK( st.st_mode ) ) &&
+	    ( follow_symlinks == true ) &&
+	    ( isCorrupt == false ) &&
+	    ( S_ISREG( dst.st_mode ) ) ) useregcopy = true;
+  
+  if ( useregcopy == false ) return 1;
+  
+  fdr = ::worker_open( source, O_RDONLY, 0 );
+  if ( fdr == -1 ) {
+    // can't open inputfile
+    return 1;
+  }
+  
+  fdw = ::worker_open( dest, O_CREAT | O_TRUNC | O_WRONLY, S_IRUSR );
+  if ( fdw == -1 ) {
+    ::worker_close( fdr );
+    return 1;
+  } 
+
+  writebytes = -1;
+  erg = 0;
+  do {
+    readbytes = worker_read( fdr, buf, BUFSIZE );
+    if ( readbytes < 0 ) {
+      // error while reading
+      erg = 1;
+      break;
+    } else if ( readbytes == 0 ) {
+      break;
+    } else {
+      writebytes = worker_write( fdw, buf, readbytes );
+      if ( writebytes != readbytes ) {
+	// something went wrong
+	erg = 1;
+	break;
+      }
+    }
+  } while ( ( readbytes > 0 ) &&
+	    ( cancel == false ) );
+
+  ::worker_close( fdw );
+  ::worker_close( fdr );
+  return erg;
+#undef BUFSIZE
+}
