@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: datei.h,v 1.55 2004/12/12 22:11:21 ralf Exp $ */
+/* $Id: datei.h,v 1.58 2005/02/07 22:40:34 ralf Exp $ */
 
 #ifndef DATEI_H
 #define DATEI_H
@@ -100,9 +100,13 @@ public:
   static char *shrinkFilename( const char *str, int maxlength );
   static loff_t fileSize( const char * );
   static char *getRelativePath( const char *source, const char *destdir );
+  static int copyfile( const char *dest, const char *source );
 private:
-  FILE *fp;
+  int fd;
   long error;
+  int putCharacter( int c );
+  int getCharacter();
+  bool iseof;
 };
 
 class FileEntry
@@ -274,9 +278,5 @@ int getOwnerStringLen(uid_t,gid_t);
 char* getOwnerString(uid_t,gid_t);
 char *resolveEnv(const char*);
 
-extern int datelen;
-
-int getDatelen();
-
 #endif
 
