@@ -1,6 +1,6 @@
 /* execlass.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2004 Ralf Hoffmann.
+ * Copyright (C) 2002-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: execlass.cc,v 1.12 2004/10/27 21:07:19 ralf Exp $ */
+/* $Id: execlass.cc,v 1.16 2005/02/07 07:06:39 ralf Exp $ */
 
 #include "execlass.h"
 #include <stdarg.h>
@@ -36,21 +36,21 @@ ExeClass::ExeClass( execlass_execute_t exetype, Worker *w )
   tmpfile = Datei::createTMPName();
   tmpoutput = Datei::createTMPName();
   tmperror = Datei::createTMPName();
-  fp = fopen( tmpoutput, "w" );
+  fp = worker_fopen( tmpoutput, "w" );
   if ( fp != NULL ) {
     /* be sure the output can only be changed be use */
-    chmod( tmpoutput, S_IRUSR | S_IWUSR | S_IXUSR );
-    fclose( fp );
+    worker_fclose( fp );
+    worker_chmod( tmpoutput, S_IRUSR | S_IWUSR | S_IXUSR );
   }
-  fp = fopen( tmperror, "w" );
+  fp = worker_fopen( tmperror, "w" );
   if ( fp != NULL ) {
     /* be sure the output can only be changed be use */
-    chmod( tmperror, S_IRUSR | S_IWUSR );
-    fclose( fp );
+    worker_fclose( fp );
+    worker_chmod( tmperror, S_IRUSR | S_IWUSR );
   }
-  fp = fopen( tmpfile, "w" );
+  fp = worker_fopen( tmpfile, "w" );
   if ( fp != NULL ) {
-    chmod( tmpfile, S_IRUSR | S_IWUSR | S_IXUSR );
+    worker_chmod( tmpfile, S_IRUSR | S_IWUSR | S_IXUSR );
     fprintf( fp, "#! /bin/sh\n\n" );
   }
   lasterror = 0;
@@ -59,13 +59,13 @@ ExeClass::ExeClass( execlass_execute_t exetype, Worker *w )
 ExeClass::~ExeClass()
 {
   if ( fp != NULL ) {
-    fclose( fp );
+    worker_fclose( fp );
   }
-  remove( tmpfile );
+  worker_unlink( tmpfile );
   _freesafe( tmpfile );
-  remove( tmpoutput );
+  worker_unlink( tmpoutput );
   _freesafe( tmpoutput );
-  remove( tmperror );
+  worker_unlink( tmperror );
   _freesafe( tmperror );
 }
 
@@ -136,7 +136,7 @@ void ExeClass::execute()
     fprintf( fp, OUTPUT_BIN, tmpoutput );
     fprintf( fp, "\n" );
   }
-  fclose( fp );
+  worker_fclose( fp );
   fp = NULL;
   system( exestr );
   _freesafe(exestr);
@@ -188,7 +188,7 @@ int ExeClass::getOutputAndRV( char **return_output, int *return_value, int *retu
   
   if ( worker != NULL ) worker->setWaitCursor();
 
-  fclose( fp );
+  worker_fclose( fp );
   fp = NULL;
 
   exestr = tmpfile;
@@ -229,9 +229,11 @@ void ExeClass::cdDir( const char *dir )
 {
   char *tstr;
   if ( ( fp != NULL ) && ( dir != NULL ) ) {
-    tstr = AGUIX_prepareForSingleQuote( dir );
-    fprintf( fp, "cd '%s'\n", tstr );
-    _freesafe( tstr );
+    if ( worker_islocal( dir ) == 1 ) {
+      tstr = AGUIX_prepareForSingleQuote( dir );
+      fprintf( fp, "cd '%s'\n", tstr );
+      _freesafe( tstr );
+    }
   }
 }
 
