@@ -1,6 +1,6 @@
 /* normalmode.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: normalmode.h,v 1.98 2004/12/12 22:18:53 ralf Exp $ */
+/* $Id: normalmode.h,v 1.100 2005/03/23 21:52:40 ralf Exp $ */
 
 #ifndef NORMALMODE_H
 #define NORMALMODE_H
@@ -197,6 +197,7 @@ public:
   class NormalMode *destmode;
   class WPUContext *wpu;
   bool take_dirs;
+  bool dontcd;
 };
 
 struct NM_startprogorder {
@@ -209,6 +210,7 @@ struct NM_startprogorder {
         NM_SHOW_OUTPUT} start;
 
   char *view_str;
+  bool dontcd;
 };
 
 struct NM_renameorder {
@@ -396,6 +398,12 @@ public:
                       const char *buttons,
                       char **return_str,
                       Requester::request_flags_t flags = Requester::REQUEST_NONE );
+  int request_choose( const char *title,
+		      const char *text,
+		      const char *choose_text,
+		      bool &choose_var,
+		      const char *buttons,
+		      Requester::request_flags_t flags = Requester::REQUEST_NONE );
   int request( CopyOpWin *cowin,
                const char *title,
                const char *text,
@@ -512,6 +520,7 @@ protected:
   time_t lastfsupdate;
   char *namestr;
   char *freespacestr;
+  enum ssh_allow_t { SSH_ASK, SSH_NEVER, SSH_ALWAYS } ssh_allow;
   
   struct timeval lastclick;
   int lastrow;
@@ -564,6 +573,7 @@ protected:
   int updateFreeSpaceStr( int ti );
   void setShowFreeSpace(bool v);
   void setUpdatetime(int nv);
+  void setSSHAllow( enum ssh_allow_t nv );
   
   int runCommand( const char*exestr,
                   const char *tmpname,
