@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: ownop.cc,v 1.32 2004/12/12 21:52:03 ralf Exp $ */
+/* $Id: ownop.cc,v 1.33 2005/02/07 07:09:35 ralf Exp $ */
 
 #include "ownop.h"
 #include "listermode.h"
@@ -40,6 +40,8 @@ OwnOp::OwnOp() : FunctionProto()
   com_str=dupstring("");
   view_str=dupstring("");
   hasConfigure = true;
+  
+  dontcd = false;
 }
 
 OwnOp::~OwnOp()
@@ -56,6 +58,7 @@ OwnOp::duplicate() const
   ta->recursive=recursive;
   ta->inbackground = inbackground;
   ta->take_dirs = take_dirs;
+  ta->dontcd = dontcd;
 
   ta->ownstart=ownstart;
 
@@ -124,6 +127,7 @@ OwnOp::save(Datei *fh)
   
   WConfig::configPutPairBool( fh, "inbackground", inbackground );
   WConfig::configPutPairBool( fh, "takedirs", take_dirs );
+  WConfig::configPutPairBool( fh, "dontcd", dontcd );
   return true;
 }
 
@@ -208,6 +212,9 @@ OwnOp::normalmodeown()
   extorder.view_str=NULL;
   if(strlen(com_str)>0) extorder.com_str=com_str;
   if(strlen(view_str)>0) extorder.view_str=view_str;
+
+  extorder.dontcd = dontcd;
+
   nm1->externprog(&extorder);
 
   if(extorder.source==extorder.NM_SPECIAL) {
@@ -225,7 +232,7 @@ OwnOp::configure()
   Button *okb,*cb,*fb, *comreqb, *comreqb2;
   StringGadget *sg[2];
   AWindow *win;
-  ChooseButton *scb,*rcb, *ibcb, *tdcb;
+  ChooseButton *scb,*rcb, *ibcb, *tdcb, *dcdcb;
   CycleButton *cyb;
   Text *ttext;
   int tw,w,h,x,y,t1,t2;
@@ -267,6 +274,12 @@ OwnOp::configure()
   tw = tdcb->getWidth() + 10;
   if ( tw > w ) w = tw;
 
+  dcdcb = (ChooseButton*)win->add( new ChooseButton( aguix, x, y, ( dontcd == true ) ? 1 : 0,
+						     catalog.getLocale( 617 ), LABEL_RIGHT, 1, 0 ) );
+  y += dcdcb->getHeight() + 5;
+  tw = dcdcb->getWidth() + 10;
+  if ( tw > w ) w = tw;
+
   ibcb = (ChooseButton*)win->add( new ChooseButton( aguix,
                                                     x,
                                                     y,
@@ -487,6 +500,7 @@ OwnOp::configure()
     separate_each_entry=(scb->getState()==1)?true:false;
     recursive=(rcb->getState()==1)?true:false;
     take_dirs = ( tdcb->getState() == 1 ) ? true : false;
+    dontcd = ( dcdcb->getState() == 1 ) ? true : false;
     inbackground = ( ibcb->getState() == 1 ) ? true : false;
     _freesafe(com_str);
     _freesafe(view_str);
@@ -674,3 +688,7 @@ void OwnOp::setTakeDirs( bool nv )
   take_dirs = nv;
 }
 
+void OwnOp::setDontCD( bool nv )
+{
+  dontcd = nv;
+}
