@@ -1,6 +1,6 @@
 /* ownop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: ownop.h,v 1.18 2004/10/27 21:08:19 ralf Exp $ */
+/* $Id: ownop.h,v 1.20 2005/02/07 22:50:08 ralf Exp $ */
 
 #ifndef OWNOP_H
 #define OWNOP_H
@@ -79,7 +79,11 @@ static const ownop_flags_t ownop_flags[] = { { "{Rs{Infotext}{Defaulttext}}", 0
                                              { "{oufE}", 33 },
                                              { "{ouFE}", 34 },
                                              { "{ouaE}", 35 },
-                                             { "{ouAE}", 36 } };
+                                             { "{ouAE}", 36 },
+					     { "{t}", 54 },
+					     { "{ut}", 55 },
+					     { "{ot}", 56 },
+					     { "{out}", 57 } };
 
 class OwnOp:public FunctionProto
 {
@@ -111,6 +115,7 @@ public:
   void setViewStr(const char*);
   void setInBackground( bool );
   void setTakeDirs( bool );
+  void setDontCD( bool );
   char *getFlag();
   static const char *name;
 protected:
@@ -119,6 +124,7 @@ protected:
   bool recursive;
   bool inbackground;
   bool take_dirs;
+  bool dontcd;
   
   ownstart_t ownstart;
 
