@@ -1,7 +1,7 @@
 /* renameop.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
  * Copyright (C) 2001-2004 Ralf Hoffmann.
- * You can contact me at: ralf.hoffmann@epost.de
+ * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: renameop.cc,v 1.10 2004/03/18 07:11:04 ralf Exp $ */
+/* $Id: renameop.cc,v 1.12 2004/12/12 21:45:53 ralf Exp $ */
 
 #include "renameop.h"
 #include "listermode.h"
@@ -84,7 +84,7 @@ RenameOp::normalmoderename()
   NormalMode *nm1=NULL;
   ListerMode *lm1=NULL;
   struct NM_renameorder renorder;
-  struct NM_specialsource *specialsource=NULL;
+  NM_specialsourceExt *specialsource=NULL;
   
   if(startlister==NULL) return 1;
   lm1=startlister->getActiveMode();
@@ -98,25 +98,23 @@ RenameOp::normalmoderename()
   else if(am->mode==am->AM_MODE_DNDACTION) {
     // insert DND-element into list
     renorder.source=renorder.NM_SPECIAL;
-    renorder.sources=new List;
-    specialsource=(struct NM_specialsource*)_allocsafe(sizeof(struct NM_specialsource));
-    specialsource->entry=NULL;
+    renorder.sources=new std::list<NM_specialsourceExt*>;
+    specialsource = new NM_specialsourceExt( NULL );
     specialsource->row=-1;
     //TODO: specialsource nach am besetzen (je nachdem wir ich das realisiere)
-    renorder.sources->addElement(specialsource);
+    renorder.sources->push_back(specialsource);
   } else if(am->mode==am->AM_MODE_SPECIAL) {
     renorder.source=renorder.NM_SPECIAL;
-    renorder.sources=new List;
-    specialsource=(struct NM_specialsource*)_allocsafe(sizeof(struct NM_specialsource));
-    specialsource->entry=(FileEntry*)am->extraInfo;
+    renorder.sources=new std::list<NM_specialsourceExt*>;
+    specialsource = new NM_specialsourceExt( am->getFE() );
     specialsource->row=-1;
-    renorder.sources->addElement(specialsource);
+    renorder.sources->push_back(specialsource);
   } else
     renorder.source=renorder.NM_ALLENTRIES;
 
   nm1->renamef(&renorder);
   if(renorder.source==renorder.NM_SPECIAL) {
-    if(specialsource!=NULL) _freesafe(specialsource);
+    if ( specialsource != NULL ) delete specialsource;
     delete renorder.sources;
   }
 
