@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: startprogop.cc,v 1.23 2004/12/12 21:22:47 ralf Exp $ */
+/* $Id: startprogop.cc,v 1.24 2005/02/07 07:12:02 ralf Exp $ */
 
 #include "startprogop.h"
 #include "listermode.h"
@@ -36,6 +36,7 @@ StartProgOp::StartProgOp() : FunctionProto()
   global=false;
   requestflags=false;
   inbackground = false;
+  dontcd = false;
   hasConfigure = true;
 }
 
@@ -55,6 +56,7 @@ StartProgOp::duplicate() const
   ta->global=global;
   ta->requestflags=requestflags;
   ta->inbackground = inbackground;
+  ta->dontcd = dontcd;
   return ta;
 }
 
@@ -111,6 +113,7 @@ StartProgOp::save(Datei *fh)
   WConfig::configPutPairBool( fh, "global", global );
   WConfig::configPutPairBool( fh, "requestflags", requestflags );
   WConfig::configPutPairBool( fh, "inbackground", inbackground );
+  WConfig::configPutPairBool( fh, "dontcd", dontcd );
   return true;
 }
 
@@ -140,6 +143,7 @@ StartProgOp::normalmodestartprog()
     tglobal=global;
     tstartprogstart=startprogstart;
     tinbackground = inbackground;
+    tdontcd = dontcd;
     tview_str=dupstring(view_str);
   }
   
@@ -168,6 +172,9 @@ StartProgOp::normalmodestartprog()
     }
     sporder.view_str=NULL;
     if(strlen(tview_str)>0) sporder.view_str=tview_str;
+
+    sporder.dontcd = tdontcd;
+
     nm1->startprog(&sporder);
     _freesafe(tview_str);
   }
@@ -188,7 +195,7 @@ StartProgOp::doconfigure(int mode)
   StringGadget *sg;
   AWindow *win;
   CycleButton *cyb;
-  ChooseButton *gcb,*rfcb=NULL, *ibcb;
+  ChooseButton *gcb,*rfcb=NULL, *ibcb, *dcdcb;
   Text *ttext;
   int tw,w,h,x,y,t1,t2;
   AGMessage *msg;
@@ -267,6 +274,18 @@ StartProgOp::doconfigure(int mode)
   tw=ibcb->getWidth()+10;
   if(tw>w) w=tw;
 
+  dcdcb = (ChooseButton*)win->add( new ChooseButton( aguix,
+						     x,
+						     y,
+						     ( dontcd == true ) ? 1 : 0,
+						     catalog.getLocale( 617 ),
+						     LABEL_RIGHT,
+						     1,
+						     0 ) );
+  y += dcdcb->getHeight() + 5;
+  tw = dcdcb->getWidth() + 10;
+  if ( tw > w ) w = tw;
+
   if(mode==0) {
     rfcb=(ChooseButton*)win->add(new ChooseButton(aguix,x,y,(requestflags==true)?1:0,
                                                  catalog.getLocale(294),LABEL_RIGHT,1,0));
@@ -417,6 +436,7 @@ StartProgOp::doconfigure(int mode)
       }
       tglobal=(gcb->getState()==1)?true:false;
       tinbackground = ( ibcb->getState() == 1 ) ? true : false;
+      tdontcd = ( dcdcb->getState() == 1 ) ? true : false;
     } else {
       _freesafe(view_str);
       view_str=dupstring(sg->getText());
@@ -436,6 +456,7 @@ StartProgOp::doconfigure(int mode)
       }
       global=(gcb->getState()==1)?true:false;
       inbackground = ( ibcb->getState() == 1 ) ? true : false;
+      dontcd = ( dcdcb->getState() == 1 ) ? true : false;
       requestflags=(rfcb->getState()==1)?true:false;
     }
   }
@@ -467,6 +488,11 @@ void StartProgOp::setInBackground( bool nv )
   inbackground = nv;
 }
 
+void StartProgOp::setDontCD( bool nv )
+{
+  dontcd = nv;
+}
+
 void StartProgOp::setViewStr( const char *nv )
 {
   if ( nv == NULL ) return;
