@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: startprogop.h,v 1.10 2004/10/27 21:09:24 ralf Exp $ */
+/* $Id: startprogop.h,v 1.11 2005/02/07 07:11:56 ralf Exp $ */
 
 #ifndef STARTPROGOP_H
 #define STARTPROGOP_H
@@ -62,6 +62,7 @@ public:
   void setRequestFlags(bool);
   void setInBackground( bool );
   void setViewStr( const char * );
+  void setDontCD( bool );
 protected:
   static const char *name;
   // Infos to save
@@ -71,6 +72,7 @@ protected:
   char *view_str;
   bool global,requestflags;
   bool inbackground;
+  bool dontcd;
   
   // temp variables
   Lister *startlister,*endlister;
@@ -79,6 +81,7 @@ protected:
   char *tview_str;
   bool tglobal,trequestflags;
   bool tinbackground;
+  bool tdontcd;
   
   int normalmodestartprog();
 };
