@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: wconfig.h,v 1.53 2004/10/27 21:09:40 ralf Exp $ */
+/* $Id: wconfig.h,v 1.54 2005/02/15 07:20:50 ralf Exp $ */
 
 #ifndef WCONFIG_H
 #define WCONFIG_H
@@ -201,6 +201,8 @@ public:
   const char *getClockbarCommand();
   void setDontCheckDirs(List*);
   List *getDontCheckDirs();
+  void setDontCheckVirtual( bool );
+  bool getDontCheckVirtual() const;
   void setShowStringForDirSize(bool nv);
   bool getShowStringForDirSize();
   void setStringForDirSize(const char *nv);
@@ -318,6 +320,7 @@ protected:
   int clockbar_updatetime;
   char *clockbar_command;
   List *dontcheckdirs;
+  bool dontcheckvirtual;
   
   struct {
     std::list<layoutID_t> orders;
@@ -392,7 +395,7 @@ protected:
   bool FTautocreate(WCFiletype *);
   void initFixTypes();
   void setDefaultConfig();
-  int configureDCD(List *);
+  int configureDCD( List *, bool * );
 
   // for loading the old config
   int parseChunk(Datei *fp);
