@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: wconfigglb.cc,v 1.4 2004/10/27 21:09:42 ralf Exp $ */
+/* $Id: wconfigglb.cc,v 1.5 2005/01/11 23:29:46 ralf Exp $ */
 
 #include "wconfig.h"
 #include "worker.h"
@@ -31,16 +31,16 @@
 #include <aguix/acontainerbb.h>
 #include <list>
 
-struct { WConfig::layoutID_t id;
-         int descr; } layoutDescr[] = { { WConfig::LO_STATEBAR, 556 },
-                                        { WConfig::LO_CLOCKBAR, 557 },
-                                        { WConfig::LO_BUTTONS, 558 },
-                                        { WConfig::LO_LISTVIEWS, 559 },
-                                        { WConfig::LO_BLL, 560 },
-                                        { WConfig::LO_LBL, 561 },
-                                        { WConfig::LO_LLB, 562 },
-                                        { WConfig::LO_BL, 563 },
-                                        { WConfig::LO_LB, 564 } };
+static struct { WConfig::layoutID_t id;
+                int descr; } layoutDescr[] = { { WConfig::LO_STATEBAR, 556 },
+					       { WConfig::LO_CLOCKBAR, 557 },
+					       { WConfig::LO_BUTTONS, 558 },
+					       { WConfig::LO_LISTVIEWS, 559 },
+					       { WConfig::LO_BLL, 560 },
+					       { WConfig::LO_LBL, 561 },
+					       { WConfig::LO_LLB, 562 },
+					       { WConfig::LO_BL, 563 },
+					       { WConfig::LO_LB, 564 } };
 typedef struct { WConfig::layoutID_t id; int group; } layoutIDGrp_t;
 layoutIDGrp_t layouts[][5] = { { { WConfig::LO_STATEBAR, 0 },
                                  { WConfig::LO_CLOCKBAR, 1 },
