@@ -1,6 +1,6 @@
 /* worker.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: worker.cc,v 1.104 2004/10/27 21:09:56 ralf Exp $ */
+/* $Id: worker.cc,v 1.110 2005/03/29 20:17:22 ralf Exp $ */
 
 #include "worker.h"
 #include "lister.h"
@@ -409,6 +409,11 @@ int main(int argc,char **argv)
     printf("           <dir1> <dir2>\tShows dir1 on the left side, dir2 on the right side\n\n");
     exit(0);
   }
+ 
+  if ( worker_tmpdir() == NULL ) {
+    exit( 0 );
+  }
+
   ugdb=new GroupHash();
   Worker *worker=new Worker(argc,argv);
   if(worker->getAGUIX()->checkX()==True) {
@@ -921,7 +926,7 @@ void Worker::about()
   int erg;
   
   tstr = (char*)_allocsafe( 1024 + 3 * A_BYTESFORNUMBER( int ) + strlen( WORKER_COMMENT ) );
-  sprintf(tstr,"Worker %d.%d.%d%s|Copyright (C) 1998 - 2004 Ralf Hoffmann",WORKER_MAJOR,WORKER_MINOR,WORKER_PATCH,WORKER_COMMENT);
+  sprintf(tstr,"Worker %d.%d.%d%s|Copyright (C) 1998 - 2005 Ralf Hoffmann",WORKER_MAJOR,WORKER_MINOR,WORKER_PATCH,WORKER_COMMENT);
   str1 = tstr;
   _freesafe( tstr );
   
@@ -967,6 +972,13 @@ void Worker::about()
   str1 += "no";
 #endif
 
+  str1 += "|Virtual file system (AVFS) usage: ";
+#ifdef HAVE_AVFS
+  str1 += "yes";
+#else
+  str1 += "no";
+#endif
+
 #ifdef USE_MEM_SYSTEM
   str1 += "|This program is compiled with SLOW memorysystem";
 #endif
@@ -1276,7 +1288,11 @@ int Worker::saveListerState()
   
   str1 = home;
   if ( len > 1 ) if ( home[ len - 1 ] != '/' ) str1 += "/";
+#ifdef USEOWNCONFIGFILES
+  str1 += "lvconf-dev";
+#else
   str1 += "lvconf";
+#endif
 
   fh = new Datei();
   if ( fh->open( str1.c_str(), "w" ) == 0 ) {
@@ -1300,7 +1316,7 @@ int Worker::saveListerState()
 int Worker::initListerState()
 {
   int pos,s;
-  char *startd[2],*tstr,*tstr2;
+  char *startd[2], *tstr;
   const char *home = wconfig->getHome();
   int len = strlen( home );
   std::string str1;
@@ -1315,10 +1331,14 @@ int Worker::initListerState()
 
   str1 = home;
   if ( len > 1 ) if ( home[ len - 1 ] != '/' ) str1 += "/";
+#ifdef USEOWNCONFIGFILES
+  str1 += "lvconf-dev";
+#else
   str1 += "lvconf";
+#endif
 
   activeside = -1;
-  fp = fopen( str1.c_str(), "r" );
+  fp = worker_fopen( str1.c_str(), "r" );
   if ( fp != NULL ) {
     yyrestart( fp );
     readtoken();
@@ -1397,7 +1417,7 @@ int Worker::initListerState()
       //      denn beim Beenden wird neue Datei geschrieben
       fprintf( stderr, "Worker:error in listview configuration (lvconf)\n" );
     }
-    fclose( fp );
+    worker_fclose( fp );
   } else {
     fh = new Datei();
     str1 = home;
@@ -1468,16 +1488,16 @@ int Worker::initListerState()
         lister[s]->switch2Mode(0);
         NormalMode *nm=(NormalMode*)lister[s]->getActiveMode();
         if(nm!=NULL) {
-          if(startd[s][0]!='/') {
-            tstr=catstring(actdir,"/");
-            tstr2=catstring(tstr,startd[s]);
-            _freesafe(tstr);
+	  tstr = HandlePathExt( startd[s] );
+
+          if ( tstr[0] != '/' ) {
+	    str1 = actdir;
+	    str1 += "/";
+	    str1 += tstr;
           } else {
-            tstr2=dupstring(startd[s]);
+	    str1 = tstr;
           }
-          tstr=HandlePathExt(tstr2);
-          _freesafe(tstr2);
-          nm->enterDir(tstr);
+          nm->enterDir( str1.c_str() );
           _freesafe(tstr);
         }
       }
@@ -1624,7 +1644,7 @@ void Worker::checkfirststart( char **setlang )
       if ( Worker::getDataDir().length() > 0 ) {
         catdir = Worker::getDataDir();
         catdir += "/catalogs";
-        dir2 = opendir( catdir.c_str() );
+        dir2 = worker_opendir( catdir.c_str() );
         if ( dir2 != NULL ) {
           while ( ( namelist = worker_readdir( dir2 ) ) != NULL ) {
             if ( strlen( namelist->d_name ) > 8 ) {
@@ -1636,7 +1656,7 @@ void Worker::checkfirststart( char **setlang )
               }
             }
           }
-          closedir(dir2);
+          worker_closedir( dir2 );
         }
       }
       // now all available languages are in the list
@@ -1663,13 +1683,13 @@ void Worker::checkfirststart( char **setlang )
       catdir = homestr;
       catdir += "/.worker";
       if(Datei::fileExists( catdir.c_str() )==false) {
-        mkdir( catdir.c_str(), 0700 );
+        worker_mkdir( catdir.c_str(), 0700 );
       }
 
       catdir = homestr;
       catdir += "/.worker/catalogs";
       if(Datei::fileExists( catdir.c_str() )==false) {
-        mkdir( catdir.c_str(), 0700 );
+        worker_mkdir( catdir.c_str(), 0700 );
       }
 
       if ( Worker::getDataDir().length() > 0 ) {
