@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: worker_commands.cc,v 1.27 2004/10/27 21:10:16 ralf Exp $ */
+/* $Id: worker_commands.cc,v 1.28 2005/03/08 22:53:22 ralf Exp $ */
 
 #include "worker.h"
 #include "worker_commands.h"
@@ -169,6 +169,9 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 47:
       fpr = new NoOperationOp();
       break;
+    case 48:
+      fpr = new GoFTPOp();
+      break;
     default:
       fpr=new DNDAction();
   }
@@ -226,6 +229,7 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if ( fpr->isName( ShowDirCacheOp::name ) == true ) type = 45;
   else if ( fpr->isName( ParentActionOp::name ) == true ) type = 46;
   else if ( fpr->isName( NoOperationOp::name ) == true ) type = 47;
+  else if ( fpr->isName( GoFTPOp::name ) == true ) type = 48;
   return type;
 }
 
