@@ -1,6 +1,6 @@
 /* worker_locale.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,15 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: worker_locale.cc,v 1.159 2004/10/31 16:48:33 ralf Exp $ */
+/* $Id: worker_locale.cc,v 1.165 2005/03/23 21:51:41 ralf Exp $ */
 
 #include "worker_locale.h"
 #include "wconfig.h"
 #include "worker.h"
 
-#define CATENTRY 617
-#define CATCOMENTRY 48
-#define CATFLAGENTRY 54
+#define CATENTRY 632
+#define CATCOMENTRY 49
+#define CATFLAGENTRY 59
 
 #define min(a,b) (((a)<(b))?(a):(b))
 
@@ -708,6 +708,24 @@ the default colors would be: 1 0 2 1 1 7 2 7" );
   catalog[614]=dupstring( "Add files of same filetype:" );
   catalog[615]=dupstring( "Add file" );
   catalog[616]=dupstring( "Remove from list" );
+  catalog[617]=dupstring( "Do not enter directory" );
+  catalog[618]=dupstring( "Could not create temporary copy of %s!" );
+  catalog[619]=dupstring( "Don't check content of virtual files" );
+  catalog[620]=dupstring( "Hostname:" );
+  catalog[621]=dupstring( "Username:" );
+  catalog[622]=dupstring( "Password:" );
+  catalog[623]=dupstring( "Store password but don't open ftp connection" );
+  catalog[624]=dupstring( "The password will be stored without encryption|in the worker configuration file!|Do really want to do this?" );
+  catalog[625]=dupstring( "No hostname or username was entered. Cannot continue!" );
+  catalog[626]=dupstring( "1 if entry is a local file, 0 for virtual file, -1 for non existing file or error" );
+  catalog[627]=dupstring( "Store password even if password was already stored previously" );
+  catalog[628]=dupstring( "The temporary copy of %s|has been changed but the original file will not be updated!" );
+  catalog[629]=dupstring( "Continue" );
+  catalog[630]=dupstring( "You are about to make a ssh connection. You should only continue if you|\
+don't need a password for a connection to the destination. Otherwise it|\
+will not work at all or you will be asked for the password many times|\
+if you have the ssh_askpass tool. Do you really want to continue?" );
+  catalog[631]=dupstring( "Don't ask me again" );
 
 //  catalog[]=dupstring( "" );
   
@@ -759,6 +777,7 @@ the default colors would be: 1 0 2 1 1 7 2 7" );
   catalogcom[45]=dupstring( "show directory cache" );
   catalogcom[46]=dupstring( "start action of parent type" );
   catalogcom[47]=dupstring( "do nothing" );
+  catalogcom[48]=dupstring( "FTP connection" );
   
   catalogflag[0]=dupstring( "Stringrequester" );
   catalogflag[1]=dupstring( "path" );
@@ -814,6 +833,11 @@ the default colors would be: 1 0 2 1 1 7 2 7" );
   catalogflag[51]=dupstring( "convert the expression inside the parentheses into a number" );
   catalogflag[52]=dupstring( "convert the expression inside the parentheses into a string" );
   catalogflag[53]=dupstring( "path to the \"scripts\" directory" );
+  catalogflag[54]=dupstring( "path to temporary copy of first file" );
+  catalogflag[55]=dupstring( "path to temporary copy of first file (no unselect)" );
+  catalogflag[56]=dupstring( "other side: path to temporary copy of first file" );
+  catalogflag[57]=dupstring( "other side: path to temporary copy of first file (no unselect)" );
+  catalogflag[58]=dupstring( "1 if string argument is a local file, 0 for virtual file, -1 for non existing file or error" );
 }
 
 WorkerLocale::~WorkerLocale()
