@@ -1,6 +1,6 @@
 /* wpucontext.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2004 Ralf Hoffmann.
+ * Copyright (C) 2002-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: wpucontext.cc,v 1.21 2004/12/12 21:22:24 ralf Exp $ */
+/* $Id: wpucontext.cc,v 1.24 2005/03/21 20:25:41 ralf Exp $ */
 
 #include "wpucontext.h"
 #include "scriptop.h"
@@ -96,6 +96,7 @@ struct wpucontext_deftokens {
   { "filelistEmpty", WPUContext::IFP_FILELISTEMPTY },
   { "toNum", WPUContext::IFP_TONUM },
   { "toStr", WPUContext::IFP_TOSTR },
+  { "isLocal", WPUContext::IFP_ISLOCAL },
   { NULL, WPUContext::IFP_NONE }
 };
 
@@ -203,6 +204,7 @@ WPUContext::~WPUContext()
   if ( extlist[1] != NULL ) {
     delete extlist[1];
   }
+  freeTempNameList();
 }
 
 int WPUContext::continueAtLabel( const char *label )
@@ -1002,6 +1004,21 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
       e->wasstring = 1;
       sprintf( e->strval, "%d", e->numval );
       break;
+    case IFP_ISLOCAL:
+      if ( ifp_match( IFP_ISLOCAL ) ) return NULL;
+      if ( ifp_match( '(' ) ) return NULL;
+      if ( ( e = ifp_expr() ) == NULL ) return NULL;
+      if ( ifp_match( ')' ) ) {
+        _freesafe( e->strval );
+        _freesafe( e );
+        return NULL;
+      }
+      e->numval = worker_islocal( e->strval );
+      _freesafe( e->strval );
+      e->strval = (char*)_allocsafe( A_BYTESFORNUMBER( e->numval ) );
+      e->wasstring = 0;
+      sprintf( e->strval, "%d", e->numval );
+      break;
     default:
       return NULL;
   }
@@ -1214,3 +1231,85 @@ bool WPUContext::getTakeDirs()
   return extorder.take_dirs;
 }
 
+const char *WPUContext::getTempName4File( const char *filename )
+{
+  std::list<temp4filename_t*>::iterator it1;
+  worker_struct_stat stbuf;
+  temp4filename_t *el1;
+  char *newtempname;
+
+  if ( filename == NULL ) return NULL;
+
+  for ( it1 = tempnamelist.begin(); it1 != tempnamelist.end(); it1++ ) {
+    if ( *it1 != NULL ) {
+      if ( (*it1)->filename != NULL ) {
+	if ( strcmp( (*it1)->filename, filename ) == 0 ) {
+	  break;
+	}
+      }
+    }
+  }
+
+  if ( it1 != tempnamelist.end() ) {
+    return (*it1)->tempname;
+  }
+
+  if ( worker_lstat( filename, &stbuf ) != 0 ) return NULL;
+
+  if ( ! S_ISREG( stbuf.st_mode ) ) return NULL;
+
+  newtempname = Datei::createTMPName();
+  if ( Datei::copyfile( newtempname, filename ) != 0 ) {
+    if ( worker->getRequester() != NULL ) {
+      char *reqstr;
+      reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 618 ) ) + strlen( filename ) + 1 );
+      sprintf( reqstr, catalog.getLocale( 618 ), filename );
+      worker->getRequester()->request( catalog.getLocale( 347 ), reqstr, catalog.getLocale( 11 ) );
+      _freesafe( reqstr );
+    }
+    
+    worker_unlink( newtempname );
+    _freesafe( newtempname );
+    return NULL;
+  }
+  
+  el1 = new temp4filename_t();
+  el1->tempname = newtempname;
+  el1->filename = dupstring( filename );
+  if ( worker_lstat( newtempname, &stbuf ) != 0 ) el1->modtime = 0;
+  else el1->modtime = stbuf.st_mtime;
+  
+  tempnamelist.push_back( el1 );
+  return newtempname;
+}
+
+void WPUContext::freeTempNameList()
+{
+  std::list<temp4filename_t*>::iterator it1;
+  worker_struct_stat stbuf;
+  bool changed;
+
+  for ( it1 = tempnamelist.begin(); it1 != tempnamelist.end(); it1++ ) {
+    if ( *it1 != NULL ) {
+      changed = false;
+
+      if ( (*it1)->tempname != NULL ) {
+	if ( worker_lstat( (*it1)->tempname, &stbuf ) != 0 ) changed = true;
+	else if ( (*it1)->modtime != stbuf.st_mtime ) changed = true;
+	
+	if ( ( changed == true ) &&
+	     ( (*it1)->filename != NULL ) &&
+	     ( worker->getRequester() != NULL ) ) {
+	  char *reqstr;
+	  reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 628 ) ) + strlen( (*it1)->filename ) + 1 );
+	  sprintf( reqstr, catalog.getLocale( 628 ), (*it1)->filename );
+	  worker->getRequester()->request( catalog.getLocale( 125 ), reqstr, catalog.getLocale( 11 ) );
+	  _freesafe( reqstr );
+	}
+	
+        worker_unlink( (*it1)->tempname );
+      }
+      delete *it1;
+    }
+  }
+}
